@@ -16,7 +16,6 @@ import java.security.PrivateKey;
 import java.security.PublicKey;
 import java.security.SecureRandom;
 import java.security.SignatureException;
-import java.security.cert.CertificateEncodingException;
 import java.security.cert.CertificateParsingException;
 import java.security.cert.X509Certificate;
 import java.util.Date;
@@ -32,9 +31,9 @@ import org.bouncycastle.asn1.x500.RDN;
 import org.bouncycastle.asn1.x500.X500Name;
 import org.bouncycastle.asn1.x500.style.BCStyle;
 import org.bouncycastle.asn1.x509.AlgorithmIdentifier;
+import org.bouncycastle.asn1.x509.Extension;
 import org.bouncycastle.asn1.x509.KeyUsage;
 import org.bouncycastle.asn1.x509.SubjectPublicKeyInfo;
-import org.bouncycastle.asn1.x509.Extension;
 import org.bouncycastle.pkcs.PKCS10CertificationRequest;
 
 import eu.emi.security.authn.x509.helpers.CertificateHelpers;
@@ -68,11 +67,11 @@ public class ProxyGeneratorHelper
 	 * @param privateKey key to sign the proxy
 	 * @return a newly created proxy certificate, wrapped together with a private key 
 	 * if it was also generated.
-	 * @throws InvalidKeyException
-	 * @throws SignatureException
-	 * @throws NoSuchAlgorithmException
-	 * @throws IOException 
-	 * @throws CertificateEncodingException
+	 * @throws InvalidKeyException invalid key exception
+	 * @throws SignatureException signature exception
+	 * @throws NoSuchAlgorithmException no such algorithm exception
+	 * @throws CertificateParsingException certificate parsing exception
+	 * @throws IOException IO exception
 	 */
 	public ProxyCertificate generate(ProxyCertificateOptions param,
 			PrivateKey privateKey) throws InvalidKeyException,
@@ -90,10 +89,11 @@ public class ProxyGeneratorHelper
 	 * @param param proxy parameters
 	 * @param privateKey key to sign the proxy
 	 * @return chain with the new proxy on the first position
-	 * @throws InvalidKeyException
-	 * @throws SignatureException
-	 * @throws NoSuchAlgorithmException
-	 * @throws CertificateEncodingException
+	 * @throws InvalidKeyException invalid key exception
+	 * @throws SignatureException signature exception
+	 * @throws NoSuchAlgorithmException no such algorithm exception
+	 * @throws CertificateParsingException certificate encoding exception
+	 * @throws IOException IO exception
 	 */
 	public X509Certificate[] generate(ProxyRequestOptions param,
 			PrivateKey privateKey) throws InvalidKeyException,
@@ -176,8 +176,8 @@ public class ProxyGeneratorHelper
 	 * has the Key Usage extension then a KeyUsage is returned which contains bitwise AND of KeyUsage flags 
 	 * from all certificates.
 	 * The CA certificates are ignored in the computation.
-	 * @param chain
-	 * @return
+	 * @param chain certificate chain
+	 * @return chain key usage
 	 */
 	public static Integer getChainKeyUsage(X509Certificate[] chain)
 	{
@@ -357,9 +357,9 @@ public class ProxyGeneratorHelper
 	
 	/**
 	 * For LEGACY proxies returns the serial from the issuing certificate. 
-	 * For the Drfat/rfc proxies returns the manually set serial, or generateas a
+	 * For the Draft/rfc proxies returns the manually set serial, or generateas a
 	 * random one if not set.
-	 * @param param
+	 * @param param proxy certificate options
 	 * @return serial number
 	 */
 	public static BigInteger establishSerial(BaseProxyCertificateOptions param)
@@ -375,10 +375,10 @@ public class ProxyGeneratorHelper
 
 	/**
 	 * Generate a correct DN for the proxy, depending on its type.
-	 * @param parentSubject
-	 * @param type
-	 * @param limited
-	 * @param serial
+	 * @param parentSubject parent subject
+	 * @param type proxy type
+	 * @param limited true if limited proxy
+	 * @param serial serial number
 	 * @return generated proxy DN
 	 */
 	public static X500Name generateDN(X500Principal parentSubject, ProxyType type, boolean limited, 
